@@ -36,8 +36,19 @@ const (
 	maxOrchestrationDirectoryDeletions int = 1000
 )
 
-type validString func(string) bool
-type modifyString func(string) string
+type (
+	validString  func(string) bool
+	modifyString func(string) string
+)
+
+var (
+	moveFileFunc          = fileutil.MoveFile
+	joinPathFunc          = filepath.Join
+	deleteFileFunc        = fileutil.DeleteFile
+	fileExistsFunc        = fileutil.Exists
+	isPrivilegedFile      = fileutil.IsPrivilegedAccessOnly
+	getDirectoryNamesFunc = fileutil.GetDirectoryNames
+)
 
 type DocumentMgr interface {
 	MoveDocumentState(fileName, srcLocationFolder, dstLocationFolder string)
@@ -84,12 +95,11 @@ func (d *DocumentFileMgr) MoveDocumentState(fileName, srcLocationFolder, dstLoca
 		d.stateLocation,
 		dstLocationFolder)
 
-	if s, err := fileutil.MoveFile(fileName, absoluteSource, absoluteDestination); s && err == nil {
+	if s, err := moveFileFunc(fileName, absoluteSource, absoluteDestination); s && err == nil {
 		log.Debugf("moved file %v from %v to %v successfully", fileName, srcLocationFolder, dstLocationFolder)
 	} else {
 		log.Debugf("moving file %v from %v to %v failed with error %v", fileName, srcLocationFolder, dstLocationFolder, err)
 	}
-
 }
 
 func (d *DocumentFileMgr) PersistDocumentState(fileName, locationFolder string, state contracts.DocumentState) {
@@ -98,8 +108,7 @@ func (d *DocumentFileMgr) PersistDocumentState(fileName, locationFolder string,
 	if err != nil {
 		log.Errorf("Failed to get short instanceID for PersistDocumentState: %v", err)
 	}
-
-	absoluteFileName := path.Join(path.Join(d.dataStorePath,
+	absoluteFileName := joinPathFunc(joinPathFunc(d.dataStorePath,
 		instanceID,
 		d.rootDirName,
 		d.stateLocation,
@@ -134,13 +143,19 @@ func (d *DocumentFileMgr) GetDocumentState(fileName, locationFolder string) cont
 		d.stateLocation,
 		locationFolder)
 
-	absoluteFileName := path.Join(filepath, fileName)
+	absoluteFileName := joinPathFunc(filepath, fileName)
 
 	var commandState contracts.DocumentState
 	var count, retryLimit int = 0, 3
 
-	if fileExists, _ := fileutil.LocalFileExist(absoluteFileName); !fileExists {
-		log.Warnf("file not found in the docState directory %v", absoluteFileName)
+	isPrivileged, err := isPrivilegedFile(absoluteFileName)
+	if !isPrivileged {
+		if os.IsNotExist(err) {
+			log.Errorf("file does not exist: %v", absoluteFileName)
+		} else {
+			log.Errorf("file has incorrect access privilege: %v, error: %v", absoluteFileName, err)
+		}
+		d.MoveDocumentState(fileName, locationFolder, appconfig.DefaultLocationOfCorrupt)
 		return commandState
 	}
 
@@ -153,7 +168,7 @@ func (d *DocumentFileMgr) GetDocumentState(fileName, locationFolder string) cont
 			time.Sleep(500 * time.Millisecond)
 			continue
 		} else {
-			//logging interim state as read from the file
+			// logging interim state as read from the file
 			jsonString, err := jsonutil.Marshal(commandState)
 			if err != nil {
 				log.Errorf("encountered error with message %v while marshalling %v to string", err, commandState)
@@ -172,7 +187,6 @@ func (d *DocumentFileMgr) GetDocumentState(fileName, locationFolder string) cont
 
 			d.MoveDocumentState(fileName, locationFolder, appconfig.DefaultLocationOfCorrupt)
 		}
-
 	}
 
 	return commandState
@@ -188,7 +202,7 @@ func (d *DocumentFileMgr) RemoveDocumentState(commandID, locationFolder string)
 
 	absoluteFileName := docStateFileName(commandID, instanceID, locationFolder)
 
-	err = fileutil.DeleteFile(absoluteFileName)
+	err = deleteFileFunc(absoluteFileName)
 	if err != nil {
 		log.Errorf("encountered error %v while deleting file %v", err, absoluteFileName)
 	} else {
@@ -210,12 +224,12 @@ func DocumentStateDir(instanceID, locationFolder string) string {
 func orchestrationDir(instanceID, orchestrationRootDirName string, folderType string) string {
 	switch folderType {
 	case appconfig.DefaultSessionRootDirName:
-		return path.Join(appconfig.DefaultDataStorePath,
+		return joinPathFunc(appconfig.DefaultDataStorePath,
 			instanceID,
 			appconfig.DefaultSessionRootDirName,
 			orchestrationRootDirName)
 	default:
-		return path.Join(appconfig.DefaultDataStorePath,
+		return joinPathFunc(appconfig.DefaultDataStorePath,
 			instanceID,
 			appconfig.DefaultDocumentRootDirName,
 			orchestrationRootDirName)
@@ -228,12 +242,12 @@ func getOrchestrationDirectoryNames(log log.T, instanceID, orchestrationRootDirN
 	// Form the path for orchestration logs dir
 	orchestrationRootDir = orchestrationDir(instanceID, orchestrationRootDirName, folderType)
 
-	if !fileutil.Exists(orchestrationRootDir) {
+	if !fileExistsFunc(orchestrationRootDir) {
 		log.Debugf("Orchestration root directory doesn't exist: %v", orchestrationRootDir)
 		return orchestrationRootDir, []string{}, nil
 	}
 
-	dirNames, err = fileutil.GetDirectoryNames(orchestrationRootDir)
+	dirNames, err = getDirectoryNamesFunc(orchestrationRootDir)
 	return orchestrationRootDir, dirNames, err
 }
 
@@ -251,7 +265,7 @@ func isAssociationRunDirName(dirName string) (matched bool) {
 
 // cleanupAssociationDirectory cleans up association directory by deleting expired association run directories from it.
 func cleanupAssociationDirectory(log log.T, deletedCount int, commandOrchestrationPath string, retentionDurationHours int) (canDeleteDirectory bool, deletedCountAfter int) {
-	subdirNames, err := fileutil.GetDirectoryNames(commandOrchestrationPath)
+	subdirNames, err := getDirectoryNamesFunc(commandOrchestrationPath)
 	if err != nil {
 		log.Infof("Error reading association orchestration directory %v: %v", commandOrchestrationPath, err)
 		return false, deletedCount
@@ -310,9 +324,11 @@ func isLegacyAssociationDirectory(log log.T, commandOrchestrationPath string) (b
 }
 
 // Global variables to throttle the impact of constantly rechecking the stale orchestration files
-var cleanupLock sync.Mutex
-var inCleanup = make(map[string]bool)
-var nextCleanup = make(map[string]time.Time) // okay that these will default to start of epoch
+var (
+	cleanupLock sync.Mutex
+	inCleanup   = make(map[string]bool)
+	nextCleanup = make(map[string]time.Time) // okay that these will default to start of epoch
+)
 
 func getLock(name string) bool {
 	cleanupLock.Lock()
@@ -397,7 +413,6 @@ func DeleteOldOrchestrationDirectories(log log.T, instanceID, orchestrationRootD
 
 	updateTime(orchestrationRootDirName)
 	log.Debugf("Completed orchestration directory clean up of %v items", deletedCount)
-
 }
 
 // DeleteSessionOrchestrationDirectories deletes expired orchestration directories based on session retentionDurationHours.
@@ -463,7 +478,6 @@ func DeleteSessionOrchestrationDirectories(log log.T, instanceID, orchestrationR
 // isOlderThan checks whether the file is older than the retention duration
 func isOlderThan(log log.T, fileFullPath string, retentionDurationHours int) bool {
 	modificationTime, err := fileutil.GetFileModificationTime(fileFullPath)
-
 	if err != nil {
 		log.Debugf("Failed to get modification time %v", err)
 		return false
