@@ -4,14 +4,14 @@
 package osdetect
 
 import (
-	"os/exec"
-	"strings"
-
 	"github.com/aws/amazon-ssm-agent/agent/log"
+	"github.com/aws/amazon-ssm-agent/agent/platform"
 
 	c "github.com/aws/amazon-ssm-agent/agent/plugins/configurepackage/envdetect/constants"
 )
 
+var getPlatformVersion = platform.PlatformVersion
+
 func DetectPkgManager(platform string, version string, family string) (string, error) {
 	return c.PackageManagerMac, nil
 }
@@ -20,15 +20,10 @@ func DetectInitSystem() (string, error) {
 	return c.InitLaunchd, nil
 }
 
-func DetectPlatform(_ log.T) (string, string, string, error) {
-	cmdOut, err := exec.Command("/usr/bin/sw_vers", "-productVersion").Output()
-	if err != nil {
+func DetectPlatform(log log.T) (string, string, string, error) {
+	if platformVersion, err := getPlatformVersion(log); err == nil {
+		return c.PlatformDarwin, platformVersion, c.PlatformFamilyDarwin, nil
+	} else {
 		return "", "", "", err
 	}
-
-	return c.PlatformDarwin, extractDarwinVersion(cmdOut), c.PlatformFamilyDarwin, nil
-}
-
-func extractDarwinVersion(data []byte) string {
-	return strings.TrimSpace(string(data))
 }
