@@ -18,6 +18,8 @@ import (
 	"errors"
 	"fmt"
 
+	"github.com/google/uuid"
+
 	"os/exec"
 
 	"path/filepath"
@@ -28,7 +30,6 @@ import (
 	"github.com/aws/amazon-ssm-agent/agent/log"
 	"github.com/aws/amazon-ssm-agent/agent/plugins/inventory/model"
 	"github.com/aws/amazon-ssm-agent/agent/plugins/pluginutil"
-	"github.com/twinj/uuid"
 )
 
 const (
@@ -54,7 +55,7 @@ func LogError(log log.T, err error) {
 }
 
 func randomString(length int) string {
-	return uuid.NewV4().String()[:length]
+	return uuid.New().String()[:length]
 }
 
 var cmdExecutor = executeCommand
