@@ -19,7 +19,6 @@ import (
 	"io"
 	"io/ioutil"
 	"os"
-	"regexp"
 	"strconv"
 	"strings"
 
@@ -289,12 +288,3 @@ func addSingleQuotesToStringValue(stringValue string) string {
 	stringValue = "'" + stringValue + "'"
 	return stringValue
 }
-
-// ValidatePluginId checks that id values are not allowing file injections
-func ValidatePluginId(id string) bool {
-	validIdValue := regexp.MustCompile(`^(\.{2}\/|~\/).*$`)
-	if validIdValue.MatchString(id) {
-		return false
-	}
-	return true
-}
