@@ -25,6 +25,8 @@ import (
 	"strings"
 	"time"
 
+	"github.com/google/uuid"
+
 	"github.com/aws/amazon-ssm-agent/agent/context"
 	"github.com/aws/amazon-ssm-agent/agent/contracts"
 	"github.com/aws/amazon-ssm-agent/agent/framework/docparser"
@@ -33,7 +35,6 @@ import (
 	messageContracts "github.com/aws/amazon-ssm-agent/agent/messageservice/contracts"
 	"github.com/aws/amazon-ssm-agent/agent/messageservice/utils"
 	"github.com/aws/amazon-ssm-agent/agent/times"
-	"github.com/twinj/uuid"
 )
 
 type IAgentMessage interface {
@@ -325,8 +326,7 @@ func parseAgentTaskMessage(context context.T,
 	agentMessage *AgentMessage) (*contracts.DocumentState, error) {
 
 	log := context.Log()
-	uuid.SwitchFormat(uuid.CleanHyphen)
-	clientId := uuid.NewV4().String()
+	clientId := uuid.New().String()
 
 	// parse message to retrieve parameters
 	parsedMessagePayload, err := deserializeAgentTaskPayload(log, *agentMessage)
@@ -523,41 +523,43 @@ func getUuid(log logger.T, byteArray []byte, offset int) (result uuid.UUID, err
 	byteArrayLength := len(byteArray)
 	if offset > byteArrayLength-1 || offset+16-1 > byteArrayLength-1 || offset < 0 {
 		log.Error("getUuid failed: Offset is invalid.")
-		return nil, errors.New("Offset is outside the byte array.")
+		return uuid.Nil, errors.New("Offset is outside the byte array.")
 	}
 
 	leastSignificantLong, err := getLong(log, byteArray, offset)
 	if err != nil {
 		log.Error("getUuid failed: failed to get uuid LSBs Long value.")
-		return nil, errors.New("Failed to get uuid LSBs long value.")
+		return uuid.Nil, errors.New("Failed to get uuid LSBs long value.")
 	}
 
 	leastSignificantBytes, err := longToBytes(log, leastSignificantLong)
 	if err != nil {
 		log.Error("getUuid failed: failed to get uuid LSBs bytes value.")
-		return nil, errors.New("Failed to get uuid LSBs bytes value.")
+		return uuid.Nil, errors.New("Failed to get uuid LSBs bytes value.")
 	}
 
 	mostSignificantLong, err := getLong(log, byteArray, offset+8)
 	if err != nil {
 		log.Error("getUuid failed: failed to get uuid MSBs Long value.")
-		return nil, errors.New("Failed to get uuid MSBs long value.")
+		return uuid.Nil, errors.New("Failed to get uuid MSBs long value.")
 	}
 
 	mostSignificantBytes, err := longToBytes(log, mostSignificantLong)
 	if err != nil {
 		log.Error("getUuid failed: failed to get uuid MSBs bytes value.")
-		return nil, errors.New("Failed to get uuid MSBs bytes value.")
+		return uuid.Nil, errors.New("Failed to get uuid MSBs bytes value.")
 	}
 
 	uuidBytes := append(mostSignificantBytes, leastSignificantBytes...)
 
-	return uuid.New(uuidBytes), nil
+	uuidFromBytes, _ := uuid.FromBytes(uuidBytes)
+
+	return uuidFromBytes, nil
 }
 
 // putUuid puts the 128 bit uuid to an array of bytes starting from the offset.
 func putUuid(log logger.T, byteArray []byte, offset int, input uuid.UUID) (err error) {
-	if input == nil {
+	if input == uuid.Nil {
 		log.Error("putUuid failed: input is null.")
 		return errors.New("putUuid failed: input is null.")
 	}
@@ -568,13 +570,13 @@ func putUuid(log logger.T, byteArray []byte, offset int, input uuid.UUID) (err e
 		return errors.New("Offset is outside the byte array.")
 	}
 
-	leastSignificantLong, err := bytesToLong(log, input.Bytes()[8:16])
+	leastSignificantLong, err := bytesToLong(log, input[8:16])
 	if err != nil {
 		log.Error("putUuid failed: Failed to get leastSignificant Long value.")
 		return errors.New("Failed to get leastSignificant Long value.")
 	}
 
-	mostSignificantLong, err := bytesToLong(log, input.Bytes()[0:8])
+	mostSignificantLong, err := bytesToLong(log, input[0:8])
 	if err != nil {
 		log.Error("putUuid failed: Failed to get mostSignificantLong Long value.")
 		return errors.New("Failed to get mostSignificantLong Long value.")
