@@ -68,6 +68,7 @@ var (
 	version                 string
 	downgrade               bool
 	manifestUrl             string
+	useDualStackEndpoint    bool
 )
 
 var (
@@ -80,6 +81,7 @@ var (
 	getDownloadManager      = managers.GetDownloadManager
 	startAgent              = servicemanagers.StartAgent
 	hasElevatedPermissions  = utilityCmn.IsRunningElevatedPermissions
+	ssmSetupCliVersion      = agentVersioning.Version
 
 	osExecutable         = os.Executable
 	evalSymLinks         = filepath.EvalSymlinks
@@ -127,6 +129,8 @@ func main() {
 			log.Close()
 		}()
 
+		log.Infof("ssm-setup-cli -version: %v", ssmSetupCliVersion)
+
 		// set & verify params needed for greengrass
 		setVerifyGreenGrassParams(log)
 
@@ -153,7 +157,7 @@ func main() {
 			log.Flush()
 			log.Close()
 		}()
-		log.Infof("ssm-setup-cli -version: %v", agentVersioning.Version)
+		log.Infof("ssm-setup-cli -version: %v", ssmSetupCliVersion)
 
 		// set proxy values
 		common.SetProxyConfig(log)
@@ -208,6 +212,14 @@ func performGreengrassSteps(log log.T, packageManager packagemanagers.IPackageMa
 			log.Warnf("Failed to configure agent with On-prem identity: %v", err)
 		}
 
+		if useDualStackEndpoint {
+			if err = configManager.UpdateAgentConfigWithUseDualStackEndpoint(); err != nil {
+				log.Warnf("Failed to configure agent with use dual-stack endpoint: %v", err)
+			} else {
+				log.Infof("Agent configured with use dual-stack endpoint")
+			}
+		}
+
 		log.Info("Starting amazon-ssm-agent install")
 		var isInstalled bool
 		var reInstallAgent bool
@@ -220,8 +232,8 @@ func performGreengrassSteps(log log.T, packageManager packagemanagers.IPackageMa
 				reInstallAgent = true
 			} else {
 				log.Infof("Agent version installed is %s", version)
-				if isVersionAlreadyInstalled, err := hasAgentAlreadyInstalled(version); err != nil || !isVersionAlreadyInstalled {
-					log.Warnf("Installed version is older/higher than expected Agent Version or Failed to compare, attempting to reinstall the agent: %w", err)
+				if isVersionAlreadyInstalled, err := hasAgentAlreadyInstalledOrNewer(version); err != nil || !isVersionAlreadyInstalled {
+					log.Warnf("Installed version is older than expected Agent Version %s or Failed to compare, attempting to reinstall the agent: %w", ssmSetupCliVersion, err)
 					reInstallAgent = true
 				} else if isVersionAlreadyInstalled {
 					osExit(0, log, "Version is already installed, not attempting to install agent")
@@ -342,7 +354,7 @@ func performOnpremSteps(log log.T, packageManager packagemanagers.IPackageManage
 
 	// Initialize download manager
 	log.Infof("Initialize download manager")
-	downloadManager := getDownloadManager(log, region, manifestUrl, nil, setupCLIArtifactsPath, isNano)
+	downloadManager := getDownloadManager(log, region, manifestUrl, nil, setupCLIArtifactsPath, isNano, useDualStackEndpoint)
 	if downloadManager == nil {
 		return fmt.Errorf("failed to intialize download manager")
 	}
@@ -514,6 +526,12 @@ func installAndVerifyAgent(log log.T,
 	if err = configManager.CreateUpdateAgentConfigWithOnPremIdentity(); err != nil {
 		return fmt.Errorf("return failed to update agent config %v", err)
 	}
+	if useDualStackEndpoint {
+		if err = configManager.UpdateAgentConfigWithUseDualStackEndpoint(); err != nil {
+			return fmt.Errorf("failed to update agent config with use dual-stack endpoint: %v", err)
+		}
+		log.Infof("Agent configured with use dual-stack endpoint")
+	}
 	log.Infof("Agent is configured successfully")
 
 	if !isTargetAgentInstalled {
@@ -678,17 +696,18 @@ func setParams() {
 	flag.BoolVar(&downgrade, "downgrade", false, "")
 
 	flag.BoolVar(&skipSignatureValidation, "skip-signature-validation", false, "")
+	flag.BoolVar(&useDualStackEndpoint, "use-dualstack-endpoint", false, "")
 
 	flag.Parse()
 }
 
-func hasAgentAlreadyInstalled(versionStr string) (bool, error) {
-	val, err := versionutil.VersionCompare(versionStr, agentVersioning.Version)
+func hasAgentAlreadyInstalledOrNewer(versionStr string) (bool, error) {
+	val, err := versionutil.VersionCompare(versionStr, ssmSetupCliVersion)
 	if err != nil {
 		return false, fmt.Errorf("failed to compare with already installed agent version: %w", err)
 	}
 
-	return val == 0, nil
+	return val >= 0, nil
 }
 
 func getExecutableFolderPath() (string, error) {
@@ -726,6 +745,7 @@ func verifyParams(log log.T, additionalVerifier func() string) {
 	log.Infof("manifest-url=%v", manifestUrl)
 	log.Infof("artifactsDir=%v", artifactsDir)
 	log.Infof("skip-signature-validation=%v", skipSignatureValidation)
+	log.Infof("use-dualstack-endpoint=%v", useDualStackEndpoint)
 
 	var errMessage string
 	errMessage += additionalVerifier()
@@ -799,6 +819,7 @@ func flagUsage() {
 	fmt.Fprintln(os.Stderr, "\t\t-activation-code  \tSSM Activation Code for Onprem environment \t(REQUIRED and paired with activation-id)")
 	fmt.Fprintln(os.Stderr, "\t\t-activation-id  \tSSM Activation ID for Onprem environment \t(REQUIRED and paired with Activation code)")
 	fmt.Fprintln(os.Stderr, "\t\t-override \t\tOverride existing registration if present \t(OPTIONAL)")
+	fmt.Fprintln(os.Stderr, "\t\t-use-dualstack-endpoint\tUse dual-stack endpoints for AWS services \t(OPTIONAL)")
 
 	fmt.Fprintln(os.Stderr, "\nCommand-line Usage for SSM agent installation alone(without registration) in ONPREM environment:")
 	fmt.Fprintln(os.Stderr, "\t-install        \tInstall the SSM Agent. Use this flag only if you want to skip registration. \t(REQUIRED)")
@@ -806,6 +827,7 @@ func flagUsage() {
 	fmt.Fprintln(os.Stderr, "\t\t-version\tVersion of the ssm agent to download and install ('stable' or 'latest'). Default set to 'stable' if agent is not already installed; otherwise, skip the installation. \t(OPTIONAL)")
 	fmt.Fprintln(os.Stderr, "\t\t-downgrade\tSet when the agent needs to be downgraded \t(OPTIONAL but REQUIRED during downgrade)")
 	fmt.Fprintln(os.Stderr, "\t\t-skip-signature-validation\tSkip signature validation \t(OPTIONAL)")
+	fmt.Fprintln(os.Stderr, "\t\t-use-dualstack-endpoint\tUse dual-stack endpoints for AWS services \t(OPTIONAL)")
 
 	fmt.Fprintln(os.Stderr, "\nCommand-line Usage for GREENGRASS environment:")
 	fmt.Fprintln(os.Stderr, "\t-artifacts-dir \tDirectory for ssm agent install package and install/register scripts")
@@ -820,6 +842,7 @@ func flagUsage() {
 	fmt.Fprintln(os.Stderr, "\t\t-activation-id  \tSSM Activation ID for Onprem environment \t\t(REQUIRED and paired with Activation code)")
 	fmt.Fprintln(os.Stderr, "\t\t-override \t\tOverride existing registration if present        \t(OPTIONAL)")
 	fmt.Fprintln(os.Stderr, "\t\t-tags     \t\tTags to attach to ssm instance on registrations  \t(OPTIONAL)")
+	fmt.Fprintln(os.Stderr, "\t\t-use-dualstack-endpoint\tUse dual-stack endpoints for AWS services \t(OPTIONAL)")
 
 }
 func initializeLogger() log.T {
