@@ -17,9 +17,7 @@
 package startup
 
 import (
-	"errors"
 	"fmt"
-	"time"
 
 	"github.com/aws/amazon-ssm-agent/agent/platform"
 	"github.com/aws/amazon-ssm-agent/agent/startup/serialport"
@@ -29,14 +27,6 @@ import (
 	"github.com/aws/aws-sdk-go/aws/session"
 )
 
-const (
-	// Retry max count for opening serial port
-	serialPortRetryMaxCount = 10
-
-	// Wait time before retrying to open serial port
-	serialPortRetryWaitTime = 5
-)
-
 // IsAllowed returns true if the current environment allows startup processor.
 func (p *Processor) IsAllowed() bool {
 	// TODO: Check if is EC2 identity type instead of calling imds, first confirm if onprem on ec2 should be allowed
@@ -52,8 +42,6 @@ func (p *Processor) IsAllowed() bool {
 
 // ExecuteTasks executes startup tasks in unix platform.
 func (p *Processor) ExecuteTasks() (err error) {
-	var sp *serialport.SerialPort
-
 	log := p.context.Log()
 	log.Info("Executing startup processor tasks")
 
@@ -71,31 +59,15 @@ func (p *Processor) ExecuteTasks() (err error) {
 		log.Warn(err)
 	}
 
-	// attempt to initialize and open the serial port.
-	// since only three minute is allowed to write logs to console during boot,
-	// it attempts to open serial port for approximately three minutes.
-	retryCount := 0
-	for retryCount < serialPortRetryMaxCount {
-		sp = serialport.NewSerialPort(log)
-		if err = sp.OpenPort(); err != nil {
-			log.Errorf("%v. Retrying in %v seconds...", err.Error(), serialPortRetryWaitTime)
-			time.Sleep(serialPortRetryWaitTime * time.Second)
-			retryCount++
-		} else {
-			break
-		}
-
-		// if the retry count hits the maximum count, log the error and return.
-		if retryCount == serialPortRetryMaxCount {
-			err = errors.New("Timeout: Serial port is in use or not available")
-			log.Errorf("Error occurred while opening serial port: %v", err.Error())
-			return
-		}
+	sp, err := serialport.NewSerialPortWithRetry(log)
+	if err != nil {
+		log.Errorf("Error occurred while opening serial port: %v", err.Error())
+		return
 	}
 
 	// defer is set to close the serial port during unexpected.
 	defer func() {
-		//serial port MUST be closed.
+		// serial port MUST be closed.
 		sp.ClosePort()
 	}()
 
