@@ -20,6 +20,8 @@ import (
 
 	agentcontracts "github.com/aws/amazon-ssm-agent/agent/contracts"
 	"github.com/aws/amazon-ssm-agent/agent/version"
+
+	"github.com/aws/amazon-ssm-agent/common/telemetry"
 	"github.com/aws/amazon-ssm-agent/core/app/context"
 	"github.com/aws/amazon-ssm-agent/core/app/credentialrefresher"
 	reboot "github.com/aws/amazon-ssm-agent/core/app/reboot/model"
@@ -122,6 +124,8 @@ func (agent *SSMCoreAgent) Stop() {
 		agent.registrar.Stop()
 	}
 
+	telemetry.Shutdown()
+
 	log.Info("Bye.")
 	log.Flush()
 }
