@@ -24,6 +24,7 @@ import (
 	"path/filepath"
 	"runtime"
 	"runtime/debug"
+	"strconv"
 	"strings"
 	"time"
 
@@ -41,11 +42,6 @@ import (
 	"github.com/nightlyone/lockfile"
 )
 
-const (
-	updateDelayFactor = 43200 // 12 hours
-	updateDelayBase   = 1800  // 1800 seconds
-)
-
 // UpdatePluginResult represents Agent update plugin result
 type UpdateResult struct {
 	StandOut      string    `json:"StandOut"`
@@ -72,6 +68,8 @@ var (
 	updateInitialize        func(string) error
 	updateDownloadResource  func(string) error
 	updateExecuteSelfUpdate func(log log.T, region string) (pid int, err error)
+	updateDelayFactor       = "43200" // 12 hours
+	updateDelayBase         = "1800"  // 1800 seconds
 )
 
 // IUpdateProvider is the interface to start/stop selfupdate component
@@ -162,7 +160,18 @@ func (u *SelfUpdate) Stop() {
 // Periodically Pulling manifest file and updater from regional S3 bucket.
 // Unzip updater and execute the updater
 func (u *SelfUpdate) updateFromS3WithDelay() {
-	nextTrigger := time.Duration(rand.Intn(updateDelayFactor)+updateDelayBase) * time.Second
+	log := u.context.Log()
+	updateDelayFactorInt, err := strconv.Atoi(updateDelayFactor)
+	if err != nil {
+		log.Errorf("updateDelayFactor has non-digits: %d", updateDelayFactor)
+		return
+	}
+	updateDelayBaseInt, err := strconv.Atoi(updateDelayBase)
+	if err != nil {
+		log.Errorf("updateDelayBase has non-digits: %d", updateDelayBase)
+		return
+	}
+	nextTrigger := time.Duration(rand.Intn(updateDelayFactorInt)+updateDelayBaseInt) * time.Second
 	select {
 	case <-time.After(nextTrigger):
 		_ = u.updateFromS3()
@@ -483,7 +492,7 @@ func (u *SelfUpdate) getPlatformName(log log.T) (platformName string, err error)
 }
 
 func (u *SelfUpdate) isAgentInstalledUsingSnap(log log.T) (result bool, err error) {
-	if _, commandErr := exec.Command("snap", "services", "amazon-ssm-agent").Output(); commandErr != nil {
+	if _, commandErr := execCommand("snap", "services", "amazon-ssm-agent").Output(); commandErr != nil {
 		log.Debugf("Error checking 'snap services amazon-ssm-agent' - %v", commandErr)
 		return false, commandErr
 	}
